@@ -91,12 +91,13 @@ interpolate <- function(x, x1, x2, y1, y2){
 
 
 # 2. CALCULATION OF DISTANCE MEASURES (Rx and Rrup)
-# For details on these derived equations, please see the following paper:
-# Kaklamanos, J., and L. G. Baise (2010).  Relationships between Distance
-# Measures in Recent Ground Motion Prediction Equations, Seismological
-# Research Letters (in review).
+# For details on these derived equations (and on the estimation of other input
+# parameters), please see the following paper:
+# Kaklamanos, J., L. G. Baise, and D. M. Boore (2011). A Framework for Estimating
+# Unknown Input Parameters when Implementing the NGA Ground Motion Prediction
+# Equations in Engineering Practice. Earthquake Spectra (in press).
 # The equation numbers and figures in this code refer to the equation numbers
-# and figures in Kaklamanos and Baise (2010).
+# and figures in Kaklamanos et al (2011).
 
 # Necessary trigonometric functions for Rx calculations
 csc <- function(x) {1/sin(x)}
@@ -131,7 +132,7 @@ Rx.calc <- function(Rjb, Ztor, W, dip, azimuth, Rrup = NA){
     if(azimuth == 90 | Rjb == 0){
 
       # Rjb > 0
-      # Case 6 in Figure 3 (Eqn 5)
+      # Case 6 in Figure 4 (Eqn 11)
       if(Rjb > 0)
         Rx <- Rjb + W*cos(d)
 
@@ -140,18 +141,18 @@ Rx.calc <- function(Rjb, Ztor, W, dip, azimuth, Rrup = NA){
         
         # If Rrup is known, then calculate Rx from Rrup
         if(is.na(Rrup) == FALSE){
-          # Case 5A in Figure 3 (Eqn 6)
+          # Case 5A in Figure 4 (Eqn 12)
           if(Rrup < Ztor*sec(d))
             Rx <- sqrt(Rrup^2 - Ztor^2)
-          # Case 5B (Eqn 7)
+          # Case 5B in Figure 4 (Eqn 13)
           else{
             if(Rrup >= Ztor*sec(d))
               Rx <- Rrup*csc(d) - Ztor*cot(d)
           }
         }
 
-        # If Rrup is unknown, assume that the site is located at
-        # the center of the surface projection of the ruptured area
+        # If Rrup is unknown, assume that the site is located at the
+        # center of the surface projection of the ruptured area (Eqn 7)
         else
           Rx <- W*cos(d)/2
       }
@@ -159,24 +160,24 @@ Rx.calc <- function(Rjb, Ztor, W, dip, azimuth, Rrup = NA){
     } else{
       if(azimuth >= 0 & azimuth != 90) {
         
-        # Cases 2 and 8 (Eqn 3)
+        # Cases 2 and 8 (Eqn 9)
         if(Rjb*abs(tan(a)) <= W*cos(d)){
           Rx <- Rjb*abs(tan(a))
 
-        # Cases 3 and 9 (Eqn 4)
+        # Cases 3 and 9 (Eqn 10)
         } else{
           if(Rjb*abs(tan(a)) > W*cos(d)){
             Rx <- Rjb*tan(a)*cos(a - asin(W*cos(d)*cos(a)/Rjb)) }
         }
       
-      # Cases 1, 4, and 7 (Eqn 8)
+      # Cases 1, 4, and 7 (Eqn 14)
       } else{
         if(azimuth >= -180 & azimuth < 0)
           Rx <- Rjb*sin(a)
       }
     }
 
-  # Special case for vertical faults
+  # Special case for vertical faults (Eqn 15)
   } else{
     if(dip == 90)
       Rx <- Rjb*sin(a)
@@ -205,38 +206,44 @@ Rrup.calc <- function(Rx, Ztor, W, dip, azimuth, Rjb = NA) {
   # Define angles in terms of radians
   d <- dip*pi/180
   a <- azimuth*pi/180
-    
+
+  # Shortcut calculation for vertical faults, if Rjb is entered (Eqn 23)
+  if(dip == 90 & is.na(Rjb) == FALSE){
+    return(sqrt(Rjb^2 + Ztor^2))
+  }
+
+
   # Calculate Rrup'
-  if(dip != 90)
-    {
-      # Zone A in Figure 5 (Eqn 10)
-      if(Rx < Ztor*tan(d)){
-        Rrup.prime <- sqrt(Rx^2 + Ztor^2)
+  if(dip != 90){
 
-      # Zone B (Eqn 11)
+    # Zone A in Figure 5 (Eqn 17)
+    if(Rx < Ztor*tan(d)){
+      Rrup.prime <- sqrt(Rx^2 + Ztor^2)
+      
+    # Zone B in Figure 5 (Eqn 18)
+    } else{
+      if(Rx >= Ztor*tan(d) & Rx <= Ztor*tan(d) + W*sec(d)){
+        Rrup.prime <- Rx*sin(d) + Ztor*cos(d)
+        
+      # Zone C in Figure 5 (Eqn 19)
       } else{
-        if(Rx >= Ztor*tan(d) & Rx <= Ztor*tan(d) + W*sec(d)){
-          Rrup.prime <- Rx*sin(d) + Ztor*cos(d)
-
-        # Zone C (Eqn 12)
-        } else{
-          if(Rx > Ztor*tan(d) + W*sec(d)){
-            Rrup.prime <- sqrt((Rx - W*cos(d))^2 + (Ztor + W*sin(d))^2)
-          }
+        if(Rx > Ztor*tan(d) + W*sec(d)){
+          Rrup.prime <- sqrt((Rx - W*cos(d))^2 + (Ztor + W*sin(d))^2)
         }
       }
     }
-  else if(dip == 90) # Eqn 16
+  } else if(dip == 90)  # Vertical faults, if Rjb is not entered
+                        # (equivalent to Eqn 23)    
     {Rrup.prime <- sqrt(Rx^2 + Ztor^2)}
 
 
   # Calculate Ry
 
-  # Eqn 13
+  # Eqn 20
   if(azimuth == 90 | azimuth == -90){
     Ry <- 0
   
-  # Eqn 14
+  # Eqn 21
   } else{
     if(azimuth == 0 | azimuth == 180 | azimuth == -180){
       if(is.na(Rjb) == TRUE)
@@ -244,13 +251,13 @@ Rrup.calc <- function(Rx, Ztor, W, dip, azimuth, Rjb = NA) {
       else
         Ry <- Rjb
       
-    # Eqn 15  
+    # Eqn 22
     } else{
       Ry <- abs(Rx*cot(a))
     }
   }
 
-  # Calculate Rrup (Eqn 9)
+  # Calculate Rrup (Eqn 16)
   Rrup <- sqrt(Rrup.prime^2 + Ry^2)
   
   return(Rrup)
